@@ -4,6 +4,15 @@ from kivy.uix.label import Label
 from .colors import BackgroundColorMixin
 
 
+class WrappingLabel(Label):
+    def __init__(self, **kwargs):
+        super(WrappingLabel, self).__init__(**kwargs)
+        self.bind(
+            width=lambda *x: self.setter('text_size')(self, (self.width, None)),
+            texture_size=lambda *x: self.setter('height')(self, self.texture_size[1])
+        )
+
+
 class ColorLabel(BackgroundColorMixin, Label):
     def __init__(self, **kwargs):
         bgcolor = kwargs.pop('bgcolor', None)
